@@ -670,7 +670,7 @@ def _get_child_relation_field_offsets(table: ir.TableExpr) -> dict[ops.TableNode
     """
     table_op = table.op()
     if isinstance(table_op, ops.Join):
-        root_tables = table_op.root_tables()
+        root_tables = [table_op.left.op(), table_op.right.op()]
         accum = itertools.accumulate((len(t.schema) for t in root_tables), initial=0)
         return dict(zip(root_tables, accum))
     return {}
